==> apache-dubbo-3.2.7.zip: dubbo-dubbo-3.2.7/dubbo-remoting/dubbo-remoting-http/src/main/java/org/apache/dubbo/remoting/http/factory/AbstractHttpClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.remoting.http.factory;

import org.apache.dubbo.common.URL;
import org.apache.dubbo.common.logger.ErrorTypeAwareLogger;
import org.apache.dubbo.common.logger.LoggerFactory;
import org.apache.dubbo.remoting.http.RestClient;
import org.apache.dubbo.remoting.http.config.HttpClientConfig;
import org.apache.dubbo.rpc.RpcException;

/**
 * AbstractHttpClientFactory
 */
public abstract class AbstractHttpClientFactory implements RestClientFactory {

    protected final ErrorTypeAwareLogger logger = LoggerFactory.getErrorTypeAwareLogger(getClass());


    // TODO   load config
    protected HttpClientConfig httpClientConfig = new HttpClientConfig();

    //////////////////////////////////////// implements start ///////////////////////////////////////////////
    @Override
    public RestClient createRestClient(URL url) throws RpcException {

        beforeCreated(url);

        // create a raw client
        RestClient restClient = doCreateRestClient(url);

        // postprocessor
        afterCreated(restClient);

        return restClient;
    }

    //////////////////////////////////////// implements end ///////////////////////////////////////////////


    ////////////////////////////////////////   inner methods  ///////////////////////////////////////////////

    protected void beforeCreated(URL url) {
    }

    protected abstract RestClient doCreateRestClient(URL url) throws RpcException;

    protected void afterCreated(RestClient client) {
    }

    ////////////////////////////////////////   inner methods  ///////////////////////////////////////////////





}

==> apache-dubbo-3.2.17.zip: dubbo-dubbo-3.2.17/dubbo-remoting/dubbo-remoting-http/src/main/java/org/apache/dubbo/remoting/http/factory/AbstractHttpClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.remoting.http.factory;

import org.apache.dubbo.common.URL;
import org.apache.dubbo.common.logger.ErrorTypeAwareLogger;
import org.apache.dubbo.common.logger.LoggerFactory;
import org.apache.dubbo.remoting.http.RestClient;
import org.apache.dubbo.remoting.http.config.HttpClientConfig;
import org.apache.dubbo.rpc.RpcException;

/**
 * AbstractHttpClientFactory
 */
public abstract class AbstractHttpClientFactory implements RestClientFactory {

    protected final ErrorTypeAwareLogger logger = LoggerFactory.getErrorTypeAwareLogger(getClass());

    // TODO   load config
    protected HttpClientConfig httpClientConfig = new HttpClientConfig();

    //////////////////////////////////////// implements start ///////////////////////////////////////////////
    @Override
    public RestClient createRestClient(URL url) throws RpcException {

        beforeCreated(url);

        // create a raw client
        RestClient restClient = doCreateRestClient(url);

        // postprocessor
        afterCreated(restClient);

        return restClient;
    }

    //////////////////////////////////////// implements end ///////////////////////////////////////////////

    ////////////////////////////////////////   inner methods  ///////////////////////////////////////////////

    protected void beforeCreated(URL url) {}

    protected abstract RestClient doCreateRestClient(URL url) throws RpcException;

    protected void afterCreated(RestClient client) {}

    ////////////////////////////////////////   inner methods  ///////////////////////////////////////////////

}
